#
# spec file for package re2
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global longver 2019-03-01
%global shortver %(echo %{longver}|sed 's|-||g')
%define libname libre2-0
Name:           re2
Version:        %{shortver}
Release:        lp150.22.2
Summary:        C++ fast alternative to backtracking RE engines
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/google/re2/
Source0:        https://github.com/google/re2/archive/%{longver}.tar.gz
Source99:       baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g. back references and generalized assertions).

%package -n %{libname}
Summary:        C++ fast alternative to backtracking RE engines
Group:          System/Libraries

%description -n %{libname}
RE2 is a C++ library providing a fast, safe, thread-friendly alternative to
backtracking regular expression engines like those used in PCRE, Perl, and
Python.

Backtracking engines are typically full of features and convenient syntactic
sugar but can be forced into taking exponential amounts of time on even small
inputs.

In contrast, RE2 uses automata theory to guarantee that regular expression
searches run in time linear in the size of the input, at the expense of some
missing features (e.g. back references and generalized assertions).

%package        devel
Summary:        C++ header files and library symbolic links for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
This package contains the C++ header files and symbolic links to the shared
libraries for %{name}. If you would like to develop programs using %{name},
you will need to install %{name}-devel.

%prep
%setup -q -n %{name}-%{longver}

%build
make %{?_smp_mflags} CXXFLAGS="%{optflags}"

%install
make install DESTDIR=%{buildroot} includedir=%{_includedir} libdir=%{_libdir}

# Suppress the static library
find %{buildroot} -name 'lib%{name}.a' -delete

%check
make %{?_smp_mflags} test

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license LICENSE
%doc AUTHORS CONTRIBUTORS README
%{_libdir}/lib%{name}.so.*

%files devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Wed Mar 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2019-03-01:
  * developer visible changes only
* Fri Jan  4 2019 astieger@suse.com
- update to 2019-01-01:
  * developer visible changes, performance tweaks and bug fixes
* Wed Oct 17 2018 Martin Pluskal <mpluskal@suse.com>
- update to 2018-10-01:
  * developer visible changes only
* Wed Sep  5 2018 astieger@suse.com
- update to 2018-09-01:
  * developer visible changes only
* Thu Aug 23 2018 astieger@suse.com
- update to 2018-08-01:
  * Fix the "DFA out of memory" error for the reverse Prog
* Fri Jul 20 2018 mpluskal@suse.com
- Simplify spec file a bit
* Fri Jul 20 2018 astieger@suse.com
- update to 2018-07-01:
  * Fix a "DFA out of memory" error
  * Update Unicode data to 11.0.0
  * Fix `-Wclass-memaccess' warnings and fallthrough macros
  * Use the standard first-byte analysis for the DFA too
* Fri Apr  6 2018 mpluskal@suse.com
- Update to version 2018-04-01
  * developer visible changes only
* Wed Mar 21 2018 astieger@suse.com
- update to 2018-03-01:
  * no longer linking against librd and libm
  * other developer visible changes
* Fri Feb  2 2018 astieger@suse.com
- update to 2018-02-01:
  * developer visible changes only
* Wed Jan  3 2018 mpluskal@suse.com
- Update to version 2018-01-01
  * No upstream changelog available
* Wed Jan  3 2018 dimstar@opensuse.org
- Add baselibs.conf: create libre2-0-32bit, dependency to
  libqt5-qtwebengine-32bit.
* Mon Dec 18 2017 mpluskal@suse.com
- Update to version 2017-12-01
  * No upstream changelog available
* Fri Nov  3 2017 mpluskal@suse.com
- Update to version 2017-11-01
  * No upstream changelog available
* Mon Sep  4 2017 mpluskal@suse.com
- Update to version 2017-07-01
  * No upstream changelog available
* Sat Jul 29 2017 mpluskal@suse.com
- Update to version 2017-07-01
  * No upstream changelog available
* Sun Jun 11 2017 mpluskal@suse.com
- Update to version 2017-06-01
  * No upstream changelog available
* Fri May 19 2017 vsistek@suse.com
- Update to version 2017-05-01
  * No upstream changelog available
* Thu Apr 13 2017 mpluskal@suse.com
- Update to version 2017-04-01
  * No upstream changelog available
* Thu Mar 16 2017 mpluskal@suse.com
- Update to version 2017-03-01
  * No upstream changelog available
* Sat Jan 14 2017 mpluskal@suse.com
- Update to version 2017-01-01
  * No upstream changelog available
* Sat Dec  3 2016 mpluskal@suse.com
- Update to version 2016-11-01:
  * No upstream changelog available
- Drop no longer needed re2-gcc61.patch
* Sat Oct 22 2016 jengelh@inai.de
- Fixup group and avoid rm indirection
* Thu Sep  8 2016 mpluskal@suse.com
- Drop releasenumber
* Wed Sep  7 2016 tchvatal@suse.com
- Version update to 2016-09-01 version
  * Various changes based on google needs, long changelog in upstream
    github repo
- Rebase spec on Fedora package
- Add patch to build with gcc 6.1:
  * re2-gcc61.patch
* Fri Dec 21 2012 aplanas@novell.com
- Initial package version.
